import React, {Component} from 'react';
import {
    StyleSheet,
    View,
    Text,
    TouchableHighlight,
    Modal,
} from 'react-native';

class AlertModal extends Component {
    render() {
        return (
            <Modal visible={this.props.visibility}
            transparent={true}
            animationType={'fade'}
            onRequestClose={()=>this.setState({visibility: false})}>
                <View style={styles.container}>
                    <View style={styles.modalContainer}>
                        <Text style={styles.modalTitle}>{this.props.title}</Text>
                        <Text style={styles.modalMessage}>{this.props.message}</Text>
                        <View style={styles.horizonLine}></View>
                        <View style={styles.row}>
                            <TouchableHighlight style={styles.cancelBtn} onPress={this.props.onCancelPressed} undlerlayColor={'#c5c5c5'}>
                                <Text style={styles.cancelBtnText}>取消</Text>
                            </TouchableHighlight>
                            <View style={styles.verticalLine}></View>
                            <TouchableHighlight style={styles.destructiveBtn} onPress={this.props.onDestructivePressed} underlayColor={'#c5c5c5'}>
                                <Text style={styles.destructiveBtnText}>确定</Text>
                            </TouchableHighlight>
                        </View>
                    </View>
                </View>
            </Modal>
        );
    }
}

export default AlertModal;

const styles = StyleSheet.create({
    container:{
        flex: 1,
        backgroundColor: 'rgba(0, 0, 0, 0.5)',
        justifyContent: 'center',
        alignItems: 'center'
    },
    modalContainer: {
        // marginLeft: 20,
        // marginRight: 20,
        width: DEVICE_SIZE.width * 0.85,
        borderRadius: 6,
        backgroundColor: 'white',
        justifyContent: 'center',
        alignItems: 'center'
    },
    modalTitle: {
        color: '#000',
        fontSize: 16,
        marginTop: 10
    },
    modalMessage: {
        color: '#333',
        fontSize: 14,
        margin: 10
    },
    row: {
        flexDirection: 'row',
        alignItems: 'center'
    },
    horizonLine: {
        backgroundColor: '#EBEBEB',
        height: 0.5,
        alignSelf: 'stretch'
    },
    verticalLine: {
        backgroundColor: '#EBEBEB',
        width: 0.5,
        alignSelf: 'stretch'
    },
    cancelBtn: {
        borderBottomLeftRadius: 6,
        padding: 7,
        flexGrow: 1,
        justifyContent:'center',
        alignItems: 'center',
        height: 44,
    },
    cancelBtnText: {
        fontSize: 16,
        color: '#333333',
    },
    destructiveBtn: {
        borderBottomRightRadius: 6,
        padding: 7,
        flexGrow: 1,
        justifyContent: 'center',
        alignItems: 'center',
        height: 44,
    },
    destructiveBtnText: {
        fontSize: 16,
        color: '#4C88FF'
    }
})